package com.fs.his.service;

import java.util.List;
import com.fs.his.domain.FsHealthHistoryTemp;
import com.fs.his.vo.FsHealthHistoryTempListUVO;

/**
 * 健康史模板Service接口
 *
 * @author fs
 * @date 2024-08-29
 */
public interface IFsHealthHistoryTempService
{
    /**
     * 查询健康史模板
     *
     * @param id 健康史模板主键
     * @return 健康史模板
     */
    public FsHealthHistoryTemp selectFsHealthHistoryTempById(Long id);

    /**
     * 查询健康史模板列表
     *
     * @param fsHealthHistoryTemp 健康史模板
     * @return 健康史模板集合
     */
    public List<FsHealthHistoryTemp> selectFsHealthHistoryTempList(FsHealthHistoryTemp fsHealthHistoryTemp);

    /**
     * 新增健康史模板
     *
     * @param fsHealthHistoryTemp 健康史模板
     * @return 结果
     */
    public int insertFsHealthHistoryTemp(FsHealthHistoryTemp fsHealthHistoryTemp);

    /**
     * 修改健康史模板
     *
     * @param fsHealthHistoryTemp 健康史模板
     * @return 结果
     */
    public int updateFsHealthHistoryTemp(FsHealthHistoryTemp fsHealthHistoryTemp);

    /**
     * 批量删除健康史模板
     *
     * @param ids 需要删除的健康史模板主键集合
     * @return 结果
     */
    public int deleteFsHealthHistoryTempByIds(Long[] ids);

    /**
     * 删除健康史模板信息
     *
     * @param id 健康史模板主键
     * @return 结果
     */
    public int deleteFsHealthHistoryTempById(Long id);

    List<FsHealthHistoryTempListUVO> selectFsHealthHistoryTempListUVO();

}
